@@ -1,45 +1,58 @@
 import requests, os, sys
-from licensing import methods
-from licensing.methods import Helpers
 import hashlib
 import smtplib, ssl
-import random, string
+import random, string, uuid
 class login:
-    k=Helpers.GetMachineCode()
+    k=uuid.getnode()
     ke=k.encode('utf-8')
     ey=hashlib.md5(ke)
     global key
     key=ey.hexdigest()
     def user_id(text):
-       print(text+Helpers.GetMachineCode())
-    def auth(auth_id):
-        if auth_id=='':
+        if text=='':
+            text=''
+        else:
+            pass
+        finger=uuid.getnode()
+        f=str(finger)
+        fi=f.encode('utf-8')
+        fin=hashlib.sha256(fi)
+        finger=fin.hexdigest()
+        print(text+finger)
+    def auth(auth):
+        if auth=='':
             print('Please Enter auth_id')
             sys.exit()
         else:
+            global auth_id
             global r
-        r=requests.get('https://pastebin.com/'+auth_id)
-    def verify(username, password):
-        if username=='' and password=='' or username=='' or password=='':
-            print('Need Username And Password For Login!')
+            au=auth.encode('utf-8')
+            auth_id=str(base64.b64decode(au))
+            r=requests.get('https://pastebin.com/raw/'+auth_id)
+    def verify(mail, username, password):
+        if username=='' and password=='' or username=='' or password=='' or mail=='':
+            print('Need Username,Password & Mail For Login!')
             sys.exit()
         else:
             pass
-        ins=username+password
+        ins=mail+username+password
         sec=ins.encode('utf-8')
         secu=hashlib.md5(sec)
         info=secu.hexdigest()
         if info in r.text:
             if key in r.text:
-                pass
+                if info+'=unblock' in r.text:
+                    pass
+                elif info+'=block' in r.text:
+                    print('This Account Is Blocked')
             else:
                 print('Unexpected Error!')
                 sys.exit()
         else:
-            print('Invalid Username Or Password!')
+            print('Invalid Username Password Or Mail!')
             sys.exit()
 class verify:
-    def verify(auth_id, mail, subject, mail_text, notlogin):
+    def verify(auth_id, mail, subject, mail_text):
         global code
         login=requests.get('https://pastebin.com/'+auth_id)
         email=mail.encode('utf-8')
